"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports["default"] = eslintConfigGenerator;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _slicedToArray2 = _interopRequireDefault(require("@babel/runtime/helpers/slicedToArray"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _path = _interopRequireDefault(require("path"));

var _fsExtra = _interopRequireDefault(require("fs-extra"));

var _ansiColors = _interopRequireDefault(require("ansi-colors"));

var _constants = _interopRequireDefault(require("../constants"));

var _isUsingTS = _interopRequireDefault(require("../utils/isUsingTS"));

var _pkgManager = _interopRequireDefault(require("../utils/pkgManager"));

function eslintConfigGenerator() {
  return _eslintConfigGenerator.apply(this, arguments);
} // detect all peerDependencies required versions for eslint-config-airbnb


function _eslintConfigGenerator() {
  _eslintConfigGenerator = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee() {
    var packagesMap, eslintPackages, isTypeScript, configurationPath, eslintConfiguration;
    return _regenerator["default"].wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            console.log(_ansiColors["default"].blue('\nConfiguring Eslint 🔨 🔨'));
            _context.next = 3;
            return fetchEslintPackagesInfo();

          case 3:
            packagesMap = _context.sent;
            eslintPackages = Object.entries(packagesMap).map( // get latest version ex: '^7.8.2 || ^8.2.4'
            function (_ref) {
              var _version$split$pop;

              var _ref2 = (0, _slicedToArray2["default"])(_ref, 2),
                  pkg = _ref2[0],
                  version = _ref2[1];

              return "".concat(pkg, "@").concat((_version$split$pop = version.split('||').pop()) === null || _version$split$pop === void 0 ? void 0 : _version$split$pop.trim());
            }); // extend airbnb configuration

            eslintPackages.unshift('eslint-config-airbnb'); // testing

            eslintPackages.push('eslint-plugin-jest', 'eslint-plugin-testing-library', 'eslint-plugin-jest-dom');
            _context.next = 9;
            return (0, _isUsingTS["default"])();

          case 9:
            isTypeScript = _context.sent;
            if (isTypeScript) eslintPackages.push('@typescript-eslint/parser', '@typescript-eslint/eslint-plugin', 'eslint-config-airbnb-typescript');
            _context.next = 13;
            return _pkgManager["default"].install(eslintPackages);

          case 13:
            configurationPath = _path["default"].join(_constants["default"].configFolder, isTypeScript ? 'eslint-react-ts.json' : 'eslint-react-js.json');
            _context.next = 16;
            return _fsExtra["default"].readJSON(configurationPath);

          case 16:
            eslintConfiguration = _context.sent;
            _context.next = 19;
            return _fsExtra["default"].writeJSON('.eslintrc.json', eslintConfiguration, {
              spaces: 2
            });

          case 19:
            _context.next = 21;
            return addScripts();

          case 21:
            console.log(_ansiColors["default"].blue('Eslint successfully configured 🎉 🎉'));

          case 22:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));
  return _eslintConfigGenerator.apply(this, arguments);
}

function fetchEslintPackagesInfo() {
  return _fetchEslintPackagesInfo.apply(this, arguments);
}

function _fetchEslintPackagesInfo() {
  _fetchEslintPackagesInfo = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee2() {
    var eslintPackagesString;
    return _regenerator["default"].wrap(function _callee2$(_context2) {
      while (1) {
        switch (_context2.prev = _context2.next) {
          case 0:
            _context2.next = 2;
            return _pkgManager["default"].runCommand('npm info "eslint-config-airbnb@latest" peerDependencies');

          case 2:
            eslintPackagesString = _context2.sent;
            return _context2.abrupt("return", JSON.parse(eslintPackagesString.replace(/'/g, '"').replace('eslint', '"eslint"')));

          case 4:
          case "end":
            return _context2.stop();
        }
      }
    }, _callee2);
  }));
  return _fetchEslintPackagesInfo.apply(this, arguments);
}

function addScripts() {
  return _addScripts.apply(this, arguments);
}

function _addScripts() {
  _addScripts = (0, _asyncToGenerator2["default"])( /*#__PURE__*/_regenerator["default"].mark(function _callee3() {
    return _regenerator["default"].wrap(function _callee3$(_context3) {
      while (1) {
        switch (_context3.prev = _context3.next) {
          case 0:
            _context3.next = 2;
            return Promise.all([_pkgManager["default"].runCommand('npm set-script eslint:check "eslint . --ext .js,.jsx,.ts,.tsx --ignore-path .gitignore --report-unused-disable-directives --max-warnings 0"'), _pkgManager["default"].runCommand('npm set-script eslint:fix "eslint . --fix --ext .js,.jsx,.ts,.tsx --ignore-path .gitignore --report-unused-disable-directives --max-warnings 0"')]);

          case 2:
          case "end":
            return _context3.stop();
        }
      }
    }, _callee3);
  }));
  return _addScripts.apply(this, arguments);
}